netapp_ontap.models.service_processor API documentation
Description: Copyright &copy; 2020 NetApp Inc. All rights reserved.

# Module `netapp_ontap.models.service_processor`

Copyright © 2020 NetApp Inc. All rights reserved.

## Classes

`class ServiceProcessorSchema (*, only: typing.Union = None, exclude: typing.Union = (), many: bool = False, context: typing.Dict = None, load_only: typing.Union = (), dump_only: typing.Union = (), partial: typing.Union = False, unknown: str = None)`

  The fields of the ServiceProcessor object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC

  ### Class variables

  `dhcp_enabled GET PATCH`

    Set to "true" to use DHCP to configure an IPv4 interface.

  `firmware_version GET`

    The version of firmware installed.

  `ipv4_interface GET POST PATCH`

    The ipv4_interface field of the service_processor.

  `ipv6_interface GET PATCH`

    The ipv6_interface field of the service_processor.

  `link_status GET`

    The link_status field of the service_processor.

    Valid choices:

    - up
    - down
    - disabled
    - unknown
  `mac_address GET`

    The mac_address field of the service_processor.

  `state GET`

    The state field of the service_processor.

    Valid choices:

    - online
    - offline
    - degraded
    - rebooting
    - unknown
    - updating
    - node_offline
    - sp_daemon_offline